# Jira Feedback Chrome Extension

A Chrome extension that allows users to capture and submit feedback directly to Jira with screenshots, screen recordings, and annotations.

## Features

- Authentication with Google and Jira
- Screenshot capture with annotation tools
- Screen recording with audio
- Text-based feedback submission
- Direct integration with Jira
- Context information collection
- Multiple feedback templates
- Customizable settings

## Setup

1. Clone the repository
2. Install dependencies:
```bash
npm install
```

3. Create a Google OAuth 2.0 client ID:
   - Go to the [Google Cloud Console](https://console.cloud.google.com)
   - Create a new project or select an existing one
   - Enable the Google OAuth2 API
   - Create credentials (OAuth 2.0 Client ID)
   - Add the client ID to manifest.json

4. Configure Jira OAuth 2.0:
   - Go to your Jira instance settings
   - Create a new OAuth 2.0 integration
   - Add the client ID and secret to the extension settings

5. Build the extension:
```bash
npm run build
```

6. Load the extension in Chrome:
   - Open Chrome and go to `chrome://extensions`
   - Enable "Developer mode"
   - Click "Load unpacked"
   - Select the `dist` directory

## Usage

1. Click the extension icon in the toolbar or use the keyboard shortcut (Ctrl+Shift+F / Cmd+Shift+F)
2. Login with your Google and Jira accounts
3. Choose a feedback type:
   - Screenshot
   - Screen recording
   - Text-based feedback
4. Add annotations or comments
5. Fill in the feedback details
6. Submit to Jira

## Development

- Run in development mode:
```bash
npm run dev
```

- Run tests:
```bash
npm test
```

- Lint code:
```bash
npm run lint
```

## Security

- OAuth 2.0 implementation for secure authentication
- Secure storage of credentials using Chrome's storage API
- HTTPS-only API communication
- Minimal permission requirements

## Contributing

1. Fork the repository
2. Create a feature branch
3. Commit your changes
4. Push to the branch
5. Create a Pull Request

## License

MIT License - see LICENSE file for details
